@@ -229,9 +229,8 @@ class AuthenticView(BrowserView):
             ISiteRoot.providedBy(self.context)
             or INavigationRoot.providedBy(self.context)
         ):
-            # callback url is expected on either navigationroot or site root
-            # so befor going on redirect
-            root = api.portal.get_navigation_root(self.context)
+            # callback url is expected on site root by authentic; so before going on redirect
+            root = api.portal.get()
             self.request.response.redirect(
                 "{0}/authentic-handler/{1}".format(
                     root.absolute_url(), getattr(self, "provider", "")
@@ -239,15 +238,20 @@ class AuthenticView(BrowserView):
             )
             return "redirecting"
         if not hasattr(self, "provider"):
+            # verify if is already connected
+            if not self.is_anon:
+                return self.redirect_next_url()
             return self.template()
         if self.provider not in cfg:
             return "Provider not supported"
         if not self.is_anon:
             if self.provider in self._provider_names:
-                raise ValueError(
-                    "Provider {0} is already connected to current "
-                    "user.".format(self.provider)
+                api.portal.show_message(
+                    message="Session already active!",
+                    request=self.request,
+                    type="Warning",
                 )
+                return self.redirect_next_url()
             # todo: some sort of CSRF check might be needed, so that
             #       not an account got connected by CSRF. Research needed.
             pass
@@ -269,22 +273,23 @@ class AuthenticView(BrowserView):
         if not self.is_anon:
             # now we delegate to PAS plugin to add the identity
             self._add_identity(result, provider_name)
-            self.request.response.redirect("{0}".format(self.context.absolute_url()))
+            return self.redirect_next_url()
         else:
             # now we delegate to PAS plugin in order to login
             self._remember_identity(result, provider_name)
             redirect_url = self.context.absolute_url()
-            if api.env.plone_version() < "5.2":
-                self.request.response.redirect("{0}/login_success".format(redirect_url))
-            else:
-                state = result.provider.params.get("state")
-                if state:
-                    decoded_state = result.provider.decode_state(state)
-                    if decoded_state:
-                        redirect_url = "{0}{1}".format(redirect_url, decoded_state)
-                self.request.response.redirect(redirect_url)
+            state = result.provider.params.get("state")
+            if state:
+                decoded_state = result.provider.decode_state(state)
+                if decoded_state:
+                    redirect_url = "{0}{1}".format(redirect_url, decoded_state)
+            self.request.response.redirect(redirect_url)
         return "redirecting"
 
     @property
     def is_anon(self):
         return api.user.is_anonymous()
+
+    def redirect_next_url(self):
+        next_url = self.request.form.get("next_url", self.context.absolute_url())
+        return self.request.response.redirect(next_url)
