@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from pas.plugins.imio.utils import authentic_cfg
+from pas.plugins.imio.utils import protocol
 from plone import api
 from Products.CMFPlone.utils import transaction_note
 from Products.Five import BrowserView
@@ -18,8 +19,8 @@ class ImioLogoutFormView(BrowserView):
         authentic_hostname = authentic_config["hostname"]
         if not authentic_hostname:
             return
-        authentic_logout_url = "https://{0}/idp/oidc/logout?post_logout_redirect_uri={1}".format(
-            authentic_hostname, api.portal.get().absolute_url()
+        authentic_logout_url = "{0}://{1}/idp/oidc/logout?post_logout_redirect_uri={2}".format(
+            protocol(), authentic_hostname, api.portal.get().absolute_url()
         )
 
         response = self.request.response
